@@ -1,6 +1,6 @@
 package Mojolicious::Plugin::TtRenderer::Engine;
 {
-  $Mojolicious::Plugin::TtRenderer::Engine::VERSION = '1.42';
+  $Mojolicious::Plugin::TtRenderer::Engine::VERSION = '1.43';
 }
 
 use warnings;
@@ -37,7 +37,7 @@ sub _init {
     if($dir=$args{cache_dir}) {
 
       if($app && substr($dir,0,1) ne '/') {
-        $dir=$app->home->rel_dir('tmp/ctpl');
+        $dir=$app->home->rel_dir($dir);
       }
     }
 
@@ -50,7 +50,6 @@ sub _init {
     my %config = (
         INCLUDE_PATH => \@renderer_paths,
         COMPILE_EXT  => '.ttc',
-        COMPILE_DIR  => ($dir || abs_path(File::Spec->tmpdir)),
         UNICODE      => 1,
         ENCODING     => 'utf-8',
         CACHE_SIZE   => 128,
@@ -58,6 +57,12 @@ sub _init {
         %{$args{template_options} || {}},
     );
 
+    $config{COMPILE_DIR} //= $dir || do {
+      my $tmpdir = File::Spec->catdir(File::Spec->tmpdir, "ttr$<");
+      mkdir $tmpdir unless -d $tmpdir;
+      $tmpdir;
+    };
+
     $config{LOAD_TEMPLATES} =
       [Mojolicious::Plugin::TtRenderer::Provider->new(%config, renderer => $app->renderer)]
       unless $config{LOAD_TEMPLATES};
